@@ -17,8 +17,10 @@ import socket
 import ssl
 
 from .. import errors
+from .. import extent
 from .. import http
-from . import image
+
+from . common import CLOSED
 
 log = logging.getLogger("backends.http")
 
@@ -52,8 +54,8 @@ class Backend:
 
     def __init__(self, url, cafile=None, secure=True, connect_timeout=10,
                  read_timeout=60, connect=True):
-        log.info("Open backend netloc=%r path=%r cafile=%r secure=%r",
-                 url.netloc, url.path, cafile, secure)
+        log.debug("Open netloc=%r path=%r cafile=%r secure=%r",
+                  url.netloc, url.path, cafile, secure)
         self.url = url
         self._cafile = cafile
         self._secure = secure
@@ -65,7 +67,7 @@ class Backend:
 
         # Initlized during connection.
         self._context = None
-        self._con = None
+        self._con = CLOSED
         self._can_extents = False
         self._can_zero = False
         self._can_flush = False
@@ -133,6 +135,7 @@ class Backend:
             self._optimize_connection(options.get("unix_socket"))
         except Exception:
             self._con.close()
+            self._con = CLOSED
             raise
 
     @property
@@ -296,7 +299,7 @@ class Backend:
 
         if not self._can_extents:
             if context == "zero":
-                yield image.ZeroExtent(0, self.size(), False, False)
+                yield extent.ZeroExtent(0, self.size(), False, False)
                 return
             else:
                 raise errors.UnsupportedOperation(
@@ -335,9 +338,11 @@ class Backend:
         return self._size
 
     def close(self):
-        log.info("Close backend netloc=%r path=%r",
-                 self.url.netloc, self.url.path)
-        self._con.close()
+        if self._con is not CLOSED:
+            log.debug("Close netloc=%r path=%r",
+                      self.url.netloc, self.url.path)
+            self._con.close()
+            self._con = CLOSED
 
     def __enter__(self):
         return self
@@ -512,7 +517,7 @@ class Backend:
 
         extents = json.loads(data.decode("utf-8"))
 
-        cls = image.ZeroExtent if context == "zero" else image.DirtyExtent
+        cls = extent.ZeroExtent if context == "zero" else extent.DirtyExtent
         for ext in extents:
             yield cls.from_dict(ext)
 
